<?php

namespace App\Console;

use App\Console\Commands\SendDailyNotification;
use App\Jobs\SendReminderEmail;
use App\User;
use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;

class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
        SendDailyNotification::class,
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule  $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {
        $schedule
            ->command('send:daily')
            ->cron('0 */6 * * *');

        $schedule->call(function() {
            $users = User::where('email_verified_at', '=', null)
                ->get();
            foreach ($users as $user) {
                dispatch((new SendReminderEmail($user)));
            }
        })->daily();
    }

    /**
     * Register the commands for the application.
     *
     * @return void
     */
    protected function commands()
    {
        $this->load(__DIR__.'/Commands');

        require base_path('routes/console.php');
    }
}
